exceptiontools.MissingSpannerError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError

.. autoclass:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__delattr__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getitem__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getslice__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__repr__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setattr__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setstate__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__str__
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__unicode__

Bases
-----

- :py:class:`exceptions.Exception <exceptions.Exception>`

- :py:class:`exceptions.BaseException <exceptions.BaseException>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__unicode__
   :noindex:
